<?php
/**
 * IT Company Lite Theme Customizer
 *
 * @package IT Company Lite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function it_company_lite_custom_controls() {

    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'it_company_lite_custom_controls' );

function it_company_lite_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	//add home page setting pannel
	$wp_customize->add_panel( 'it_company_lite_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'it-company-lite' ),
	    'description' => __( 'Description of what this panel does.', 'it-company-lite' ),
	) );

	$wp_customize->add_section( 'it_company_lite_left_right', array(
    	'title'      => __( 'General Settings', 'it-company-lite' ),
		'priority'   => 30,
		'panel' => 'it_company_lite_panel_id'
	) );

	$wp_customize->add_setting('it_company_lite_width_option',array(
        'default' => __('Full Width','it-company-lite'),
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control(new IT_Company_Lite_Image_Radio_Control($wp_customize, 'it_company_lite_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','it-company-lite'),
        'description' => __('Here you can change the width layout of Website.','it-company-lite'),
        'section' => 'it_company_lite_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/assets/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/assets/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/assets/images/boxed-width.png',
    ))));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('it_company_lite_theme_options',array(
        'default' => __('Right Sidebar','it-company-lite'),
        'sanitize_callback' => 'it_company_lite_sanitize_choices'	        
	) );
	$wp_customize->add_control('it_company_lite_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','it-company-lite'),
        'description' => __('Here you can change the sidebar layout for posts. ','it-company-lite'),
        'section' => 'it_company_lite_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','it-company-lite'),
            'Right Sidebar' => __('Right Sidebar','it-company-lite'),
            'One Column' => __('One Column','it-company-lite'),
            'Three Columns' => __('Three Columns','it-company-lite'),
            'Four Columns' => __('Four Columns','it-company-lite'),
            'Grid Layout' => __('Grid Layout','it-company-lite')
        ),
	));

	$wp_customize->add_setting('it_company_lite_page_layout',array(
        'default' => __('One Column','it-company-lite'),
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control('it_company_lite_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','it-company-lite'),
        'description' => __('Here you can change the sidebar layout for pages. ','it-company-lite'),
        'section' => 'it_company_lite_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','it-company-lite'),
            'Right Sidebar' => __('Right Sidebar','it-company-lite'),
            'One Column' => __('One Column','it-company-lite')
        ),
	) );

	//Topbar
	$wp_customize->add_section( 'it_company_lite_topbar', array(
    	'title'      => __( 'Topbar Settings', 'it-company-lite' ),
		'priority'   => 30,
		'panel' => 'it_company_lite_panel_id'
	) );

	$wp_customize->add_setting('it_company_lite_location',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('it_company_lite_location',array(
		'label'	=> __('Add Location','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '123 Dummy Stret, USA', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_email_address',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('it_company_lite_email_address',array(
		'label'	=> __('Add Email Address','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'support@example.com', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_inquiry_btn_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('it_company_lite_inquiry_btn_text',array(
		'label'	=> __('Add Button Text','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'INQUIRY', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_inquiry_btn_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('it_company_lite_inquiry_btn_link',array(
		'label'	=> __('Add Button Link','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'https://example.com', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_phone',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('it_company_lite_phone',array(
		'label'	=> __('Add Phone no.','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '+00 123 456 7890', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_topbar',
		'type'=> 'text'
	));
    
	//Slider
	$wp_customize->add_section( 'it_company_lite_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'it-company-lite' ),
		'priority'   => null,
		'panel' => 'it_company_lite_panel_id'
	) );

	$wp_customize->add_setting( 'it_company_lite_slider_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_slider_hide_show',array(
          'label' => esc_html__( 'Show / Hide Slider','it-company-lite' ),
          'section' => 'it_company_lite_slidersettings'
    )));

	for ( $count = 1; $count <= 4; $count++ ) {

		$wp_customize->add_setting( 'it_company_lite_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'it_company_lite_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'it_company_lite_slider_page' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'it-company-lite' ),
			'description' => __('Slider image size (1500 x 590)','it-company-lite'),
			'section'  => 'it_company_lite_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	//content layout
	$wp_customize->add_setting('it_company_lite_slider_content_option',array(
        'default' => __('Center','it-company-lite'),
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control(new IT_Company_Lite_Image_Radio_Control($wp_customize, 'it_company_lite_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','it-company-lite'),
        'section' => 'it_company_lite_slidersettings',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/slider-content1.png',
            'Center' => get_template_directory_uri().'/assets/images/slider-content2.png',
            'Right' => get_template_directory_uri().'/assets/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'it_company_lite_slider_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'it_company_lite_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','it-company-lite' ),
		'section'     => 'it_company_lite_slidersettings',
		'type'        => 'range',
		'settings'    => 'it_company_lite_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Opacity
	$wp_customize->add_setting('it_company_lite_slider_opacity_color',array(
      'default'              => 0.4,
      'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));

	$wp_customize->add_control( 'it_company_lite_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','it-company-lite' ),
	'section'     => 'it_company_lite_slidersettings',
	'type'        => 'select',
	'settings'    => 'it_company_lite_slider_opacity_color',
	'choices' => array(
      '0' =>  esc_attr('0','it-company-lite'),
      '0.1' =>  esc_attr('0.1','it-company-lite'),
      '0.2' =>  esc_attr('0.2','it-company-lite'),
      '0.3' =>  esc_attr('0.3','it-company-lite'),
      '0.4' =>  esc_attr('0.4','it-company-lite'),
      '0.5' =>  esc_attr('0.5','it-company-lite'),
      '0.6' =>  esc_attr('0.6','it-company-lite'),
      '0.7' =>  esc_attr('0.7','it-company-lite'),
      '0.8' =>  esc_attr('0.8','it-company-lite'),
      '0.9' =>  esc_attr('0.9','it-company-lite')
	),
	));

	//About Section
	$wp_customize->add_section( 'it_company_lite_about_section' , array(
    	'title'      => __( 'About us', 'it-company-lite' ),
		'priority'   => null,
		'panel' => 'it_company_lite_panel_id'
	) );

	$wp_customize->add_setting('it_company_lite_section_main_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('it_company_lite_section_main_title',array(
		'label'	=> __('Section Title','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'ABOUT US', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_about_section',
		'setting'=> 'it_company_lite_section_main_title',
		'type'=> 'text'
	));	

	$wp_customize->add_setting('it_company_lite_section_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('it_company_lite_section_text',array(
		'label'	=> __('Section Text Line','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit.', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_about_section',
		'setting'=> 'it_company_lite_section_text',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'it_company_lite_about_page', array(
		'default'           => '',
		'sanitize_callback' => 'it_company_lite_sanitize_dropdown_pages'
	) );
	$wp_customize->add_control( 'it_company_lite_about_page', array(
		'label'    => __( 'About Page', 'it-company-lite' ),
		'section'  => 'it_company_lite_about_section',
		'type'     => 'dropdown-pages'
	) );

	//About excerpt
	$wp_customize->add_setting( 'it_company_lite_about_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'it_company_lite_about_excerpt_number', array(
		'label'       => esc_html__( 'About Excerpt length','it-company-lite' ),
		'section'     => 'it_company_lite_about_section',
		'type'        => 'range',
		'settings'    => 'it_company_lite_about_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog Post
	$wp_customize->add_section('it_company_lite_blog_post',array(
		'title'	=> __('Blog Post Settings','it-company-lite'),
		'panel' => 'it_company_lite_panel_id',
	));	

	$wp_customize->add_setting( 'it_company_lite_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','it-company-lite' ),
        'section' => 'it_company_lite_blog_post'
    )));

    $wp_customize->add_setting( 'it_company_lite_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_toggle_author',array(
		'label' => esc_html__( 'Author','it-company-lite' ),
		'section' => 'it_company_lite_blog_post'
    )));

    $wp_customize->add_setting( 'it_company_lite_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_toggle_comments',array(
		'label' => esc_html__( 'Comments','it-company-lite' ),
		'section' => 'it_company_lite_blog_post'
    )));

    $wp_customize->add_setting( 'it_company_lite_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'it_company_lite_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','it-company-lite' ),
		'section'     => 'it_company_lite_blog_post',
		'type'        => 'range',
		'settings'    => 'it_company_lite_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Content Craetion
	$wp_customize->add_section( 'it_company_lite_content_section' , array(
    	'title' => __( 'Customize Home Page', 'it-company-lite' ),
		'priority' => null,
		'panel' => 'it_company_lite_panel_id'
	) );

	$wp_customize->add_setting('it_company_lite_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	) );

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new IT_Company_Lite_Content_Creation( $wp_customize, 'it_company_lite_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','it-company-lite' ),
		),
		'section' => 'it_company_lite_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'it-company-lite' ),
	) ) );

	//Footer Text
	$wp_customize->add_section('it_company_lite_footer',array(
		'title'	=> __('Footer','it-company-lite'),
		'description'=> __('This section will appear in the footer','it-company-lite'),
		'panel' => 'it_company_lite_panel_id',
	));	
	
	$wp_customize->add_setting('it_company_lite_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('it_company_lite_footer_text',array(
		'label'	=> __('Copyright Text','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Copyright 2018, .....', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_footer',
		'setting'=> 'it_company_lite_footer_text',
		'type'=> 'text'
	));	

	$wp_customize->add_setting( 'it_company_lite_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','it-company-lite' ),
      	'section' => 'it_company_lite_footer'
    )));

	$wp_customize->add_setting('it_company_lite_scroll_top_alignment',array(
        'default' => __('Right','it-company-lite'),
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control(new IT_Company_Lite_Image_Radio_Control($wp_customize, 'it_company_lite_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','it-company-lite'),
        'section' => 'it_company_lite_footer',
        'settings' => 'it_company_lite_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/layout1.png',
            'Center' => get_template_directory_uri().'/assets/images/layout2.png',
            'Right' => get_template_directory_uri().'/assets/images/layout3.png'
    ))));
}

add_action( 'customize_register', 'it_company_lite_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class IT_Company_Lite_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'IT_Company_Lite_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(new IT_Company_Lite_Customize_Section_Pro($manager,'example_1',array(
			'priority'   => 1,
			'title'    => esc_html__( 'IT COMPANY PRO', 'it-company-lite' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'it-company-lite' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/it-company-wordpress-theme/'),
		)));

		$manager->add_section(new IT_Company_Lite_Customize_Section_Pro($manager,'example_2',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'it-company-lite' ),
			'pro_text' => esc_html__( 'DOCS', 'it-company-lite' ),
			'pro_url'  => admin_url('themes.php?page=it_company_lite_guide'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'it-company-lite-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'it-company-lite-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
IT_Company_Lite_Customize::get_instance();